@@ -57,7 +57,7 @@ class Env(BaseModel):
 
 {env_init_src}
 
-    """
+"""
 
     if path_utils.path_exists(python_env_path):
         env_src = path_utils.read_text(python_env_path)
@@ -70,6 +70,8 @@ class Env(BaseModel):
                 result = result.removesuffix("\n")
             while env_src.startswith("\n"):
                 env_src = env_src.removeprefix("\n")
+            while env_src.startswith(" "):
+                env_src = env_src[1:]
             result += f"{env_src}"
     return result
 
